import { expect } from 'chai';
import { CodeMirrorAdapter } from './cm_adapter';
import { StatusMessage } from '../jupyterlab/jl_adapter';
import { CodeMirrorLSPFeature } from './feature';
import { FileEditorFeatureTestEnvironment } from './testutils';
describe('CodeMirrorAdapter', () => {
    let env;
    beforeEach(() => (env = new FileEditorFeatureTestEnvironment()));
    afterEach(() => env.dispose());
    describe('Works with VirtualFileEditor', () => {
        let dummy_components_manager;
        let connection;
        it('updates on change', async () => {
            class UpdateReceivingFeature extends CodeMirrorLSPFeature {
                constructor() {
                    super(...arguments);
                    this.name = 'UpdateReceivingFeature';
                    this.received_update = false;
                    this.last_change = null;
                }
                afterChange(change, root_position) {
                    this.received_update = true;
                    this.last_change = change;
                    this.last_change_position = root_position;
                }
            }
            connection = env.create_dummy_connection();
            dummy_components_manager = env.create_dummy_components();
            let virtual_editor = env.virtual_editor;
            let feature = new UpdateReceivingFeature(virtual_editor, virtual_editor.virtual_document, connection, dummy_components_manager, new StatusMessage());
            let adapter = new CodeMirrorAdapter(virtual_editor, virtual_editor.virtual_document, dummy_components_manager, [feature]);
            env.ce_editor.model.value.text = 'f';
            await virtual_editor.update_documents();
            expect(feature.received_update).to.equal(false);
            env.ce_editor.model.value.text = 'fo';
            await virtual_editor.update_documents();
            await adapter.updateAfterChange();
            expect(feature.received_update).to.equal(true);
            expect(feature.last_change.text[0]).to.equal('fo');
            connection.close();
        });
    });
});
//# sourceMappingURL=cm_adapter.spec.js.map