import { DataConnector } from '@jupyterlab/coreutils';
import { CompletionHandler, ContextConnector, CompletionConnector } from '@jupyterlab/completer';
import { CodeEditor } from '@jupyterlab/codeeditor';
import { CompletionTriggerKind } from '../../../lsp';
import { IClientSession } from '@jupyterlab/apputils';
import { VirtualDocument } from '../../../virtual/document';
import { VirtualEditor } from '../../../virtual/editor';
import { IRootPosition, IVirtualPosition } from '../../../positioning';
import { LSPConnection } from '../../../connection';
/**
 * A LSP connector for completion handlers.
 */
export declare class LSPConnector extends DataConnector<CompletionHandler.IReply, void, CompletionHandler.IRequest> {
    isDisposed: boolean;
    private _editor;
    private _connections;
    private _context_connector;
    private _kernel_connector;
    private _kernel_and_context_connector;
    protected options: LSPConnector.IOptions;
    virtual_editor: VirtualEditor;
    private trigger_kind;
    private suppress_auto_invoke_in;
    /**
     * Create a new LSP connector for completion requests.
     *
     * @param options - The instantiation options for the LSP connector.
     */
    constructor(options: LSPConnector.IOptions);
    dispose(): void;
    protected get _has_kernel(): boolean;
    protected get _kernel_language(): string;
    get fallback_connector(): ContextConnector | CompletionConnector;
    transform_from_editor_to_root(position: CodeEditor.IPosition): IRootPosition;
    /**
     * Fetch completion requests.
     *
     * @param request - The completion request text and details.
     */
    fetch(request: CompletionHandler.IRequest): Promise<CompletionHandler.IReply>;
    hint(token: CodeEditor.IToken, typed_character: string, start: IVirtualPosition, end: IVirtualPosition, cursor: IVirtualPosition, document: VirtualDocument, position_in_token: number): Promise<CompletionHandler.IReply>;
    private merge_replies;
    with_trigger_kind(kind: CompletionTriggerKind, fn: Function): any;
}
/**
 * A namespace for LSP connector statics.
 */
export declare namespace LSPConnector {
    /**
     * The instantiation options for cell completion handlers.
     */
    interface IOptions {
        /**
         * The editor used by the LSP connector.
         */
        editor: CodeEditor.IEditor;
        virtual_editor: VirtualEditor;
        /**
         * The connections to be used by the LSP connector.
         */
        connections: Map<VirtualDocument.id_path, LSPConnection>;
        session?: IClientSession;
    }
}
