/// <reference types="react" />
import { VDomModel, VDomRenderer } from '@jupyterlab/apputils';
import '../../../../style/statusbar.css';
import * as SCHEMA from '../../../_schema';
import { Popup } from '@jupyterlab/statusbar';
import { JupyterLabWidgetAdapter } from '../jl_adapter';
import { VirtualDocument } from '../../../virtual/document';
import { LSPConnection } from '../../../connection';
import { DocumentConnectionManager } from '../../../connection_manager';
import { ILanguageServerManager } from '../../../tokens';
export interface IListProps {
    /**
     * A title to display.
     */
    title: string;
    list: any[];
    /**
     * By default the list will be expanded; to change the initial state to collapsed, set to true.
     */
    startCollapsed?: boolean;
}
export interface ICollapsibleListStates {
    isCollapsed: boolean;
}
/**
 * StatusBar item.
 */
export declare class LSPStatus extends VDomRenderer<LSPStatus.Model> {
    protected _popup: Popup;
    /**
     * Construct a new VDomRenderer for the status item.
     */
    constructor();
    /**
     * Render the status item.
     */
    render(): JSX.Element;
    handleClick: () => void;
}
declare type StatusCode = 'waiting' | 'initializing' | 'initialized' | 'connecting';
export interface IStatus {
    connected_documents: Set<VirtualDocument>;
    initialized_documents: Set<VirtualDocument>;
    open_connections: Array<LSPConnection>;
    detected_documents: Set<VirtualDocument>;
    status: StatusCode;
}
export declare namespace LSPStatus {
    /**
     * A VDomModel for the LSP of current file editor/notebook.
     */
    class Model extends VDomModel {
        server_extension_status: SCHEMA.ServersResponse;
        language_server_manager: ILanguageServerManager;
        private _connection_manager;
        get available_servers(): Array<SCHEMA.LanguageServerSession>;
        get supported_languages(): Set<string>;
        private is_server_running;
        get documents_by_server(): Map<SCHEMA.LanguageServerSession, Map<string, VirtualDocument[]>>;
        get servers_available_not_in_use(): Array<SCHEMA.LanguageServerSession>;
        get detected_languages(): Set<string>;
        get missing_languages(): Array<string>;
        get status(): IStatus;
        get status_icon(): string;
        get short_message(): string;
        get feature_message(): string;
        get long_message(): string;
        get adapter(): JupyterLabWidgetAdapter | null;
        set adapter(adapter: JupyterLabWidgetAdapter | null);
        get connection_manager(): DocumentConnectionManager;
        set connection_manager(connection_manager: DocumentConnectionManager);
        private _onChange;
        private _adapter;
    }
}
export {};
